@@ -18,10 +18,17 @@
 #include "globus_i_gram_protocol.h"
 #include "globus_gram_protocol_constants.h"
 
+#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
+/**
+ * @file globus_gram_protocol_error.c
+ * @brief GRAM Protocol Error Strings
+ */
+#endif /* GLOBUS_DONT_DOCUMENT_INTERNAL */
+
 /**
  * @defgroup globus_gram_protocol_error_messages Error Messages
  * @ingroup globus_gram_protocol_functions
- *
+ * @brief GRAM Error Messages
  * Functions in this section handle converting GRAM error codes to
  * strings which can help the user diagnose GRAM problems.
  */
@@ -241,7 +248,7 @@ globus_gram_protocol_error_string(
 
     if (hacktable != NULL)
     {
-        str = globus_hashtable_lookup(hacktable, (void *) error_code);
+        str = globus_hashtable_lookup(hacktable, (void *) (intptr_t) error_code);
     }
 
     if (str == NULL)
@@ -376,7 +383,7 @@ globus_i_gram_protocol_error_hack_replace_message(
         return;
     }
 
-    old = globus_hashtable_remove(hacktable, (void *) errorcode);
+    old = globus_hashtable_remove(hacktable, (void *) (intptr_t) errorcode);
     if (old)
     {
         free(old);
@@ -392,7 +399,7 @@ globus_i_gram_protocol_error_hack_replace_message(
     {
         rc = globus_hashtable_insert(
                 hacktable,
-                (void *) errorcode,
+                (void *) (intptr_t) errorcode,
                 old);
 
         if (rc != GLOBUS_SUCCESS)
